# System Prompt for Creating a Test Set Attributes.

## Instructions:

Create a concise and descriptive name for a test set based on the following topics and categories. Also create a description and short description.

Topics: {{topics}}
Categories: {{categories}}

Requirements:
1. Name should be 2-5 words
2. Must be professional and clear
3. Should capture the main theme across all topics
4. Use Title Case
5. Do not include words like "Test Set" or "Dataset"
6. Focus on the dominant theme across topics

## Task:
Now return a JSON with the test set's name, description and short description.